==> mesian-v0.1.1.tar.bz2: mesian-v0.1.1/www-data/lib/Payload.php <==
<?

include_once $global["root"] . "/lib/EmailData.php";
include_once $global["root"] . "/lib/Template.php";

class Payload_Forum {

	var $data_dir;
	var $Template;
	var $storedFilename;
	var $header;

	var $total_size;

	var $id;

	function Payload_Forum ($id) {

		$this->id = $id;

		$this->__check();
	}

	function __check () {
		global $global;

		$this->data_dir = sprintf("%s/forum/%s", $global["data"], $this->id);

		if (! is_dir($this->data_dir)) {
			$retval = mkdir($this->data_dir);
		} else {
			$retval = true;
		}

		return $retval;
	}

	function insert () {
		global $string;

		$retval = true;

		// check file size.
		if (! $_FILES["user_payload"]["tmp_name"]) {
			$retval = false;
			$_SESSION["user_msg"]["content"] = $string["error6"];
		}

		if ($retval and $_FILES["user_payload"]["size"] < 1) {
			$retval = false;
			$_SESSION["user_msg"]["content"] = $string["error7"];
		}

		if ($retval and $_FILES["user_payload"]["size"] >
				$_SESSION["config_message_size_limit"]) {
			$retval = false;

			$_SESSION["user_msg"]["content"] =
				sprintf($string["error8"], $_SESSION["config_message_size_limit"]);
		}

		if ($retval) {

			$file_id = mktime().mt_rand(0,20);

			$storedFilename = $this->data_dir . "/" . $file_id;

			if (move_uploaded_file($_FILES["user_payload"]["tmp_name"], $storedFilename)) {
				$retval = true;
				$this->storedFilename = $file_id;
				$this->header = sprintf("%s;%s",
					$_FILES["user_payload"]["type"],
					$_FILES["user_payload"]["name"]);
			} else {
				$retval = false;
				$_SESSION["user_msg"]["content"] = $string["error2"];
			}
		}

		return $retval;
	}
}

class Payload {

	var $data_dir;
	var $Template;

	var $total_size;

	function Payload () {
		$this->__check();
		$this->Template = new Template;
	}

	function __check () {
		global $global;

		$this->data_dir = sprintf("%s/message/%s", $global["data"], $_SESSION["config_id"]);

		if (! is_dir($this->data_dir)) {
			$retval = mkdir($this->data_dir);
		} else {
			$retval = true;
		}

		return $retval;
	}

	function clean () {
		if (is_array($_SESSION["user_payload"]) and count($_SESSION["user_payload"]) > 0) {
			reset($_SESSION["user_payload"]);
			while (list($i, $j) = each($_SESSION["user_payload"])) {
				$this->remove($i);
			}

			unset($_SESSION["user_payload"]);
		}

		return true;
	}

	function return_name () {

		$dh = opendir($this->data_dir);

		while (($file = readdir($dh)) !== false) {

			$ff = $this->data_dir . "/" . $file;

			if (is_dir($ff)) continue;
			if (! is_file($ff)) continue;

			if (! array_key_exists($file, $_SESSION["user_payload"])) {
				$this->remove($file);
				continue;
			}
			$this->total_size += filesize($ff);

			$var[$file] = $_SESSION["user_payload"][$file]["name"];
		}

		closedir($dh);

		$retval = $var;

		return $retval;
	}

	// $name is real name.
	function check_duplicated ($name) {

		$retval = false;

		while (list($i, $j) = each($_SESSION["user_payload"])) {
			if ($j["name"] == $name) $retval = true;
		}

		return $retval;
	}

	function insert () {
		global $string;

		$retval = true;

		// check file size.
		if (! $_FILES["userfile"]["tmp_name"]) {
			$retval = false;
			$_SESSION["user_msg"]["content"] = $string["error6"];
		}

		if ($retval and $_FILES["userfile"]["size"] < 1) {
			$retval = false;
			$_SESSION["user_msg"]["content"] = $string["error7"];
		}

		if ($retval and $this->total_size + $_FILES["userfile"]["size"] >
				$_SESSION["config_message_size_limit"]) {
			$retval = false;

			$_SESSION["user_msg"]["content"] =
				sprintf($string["error8"], $_SESSION["config_message_size_limit"]);
		}

		if ($retval and $this->check_duplicated($_FILES["userfile"]["name"])) {
			$retval = false;
			$_SESSION["user_msg"]["content"] =
				sprintf($string["error1"], $_FILES["userfile"]["name"]);
		}

		if ($retval) {

			$file_id = mktime().mt_rand(0,20);

			$storedFilename = $this->data_dir . "/" . $file_id;

			if (move_uploaded_file($_FILES["userfile"]["tmp_name"], $storedFilename)) {
				$retval = true;
			} else {
				$retval = false;
				$_SESSION["user_msg"]["content"] = $string["error2"];
			}
		}

		if ($retval) {
			$_SESSION["user_payload"][$file_id]["name"] = $_FILES["userfile"]["name"];
			$_SESSION["user_payload"][$file_id]["type"] = $_FILES["userfile"]["type"];
		}

		return $retval;
	}

	function remove ($name) {
		if (! file_exists($this->data_dir . "/" . $name)) {
			$retval = false;
		} else {
			unlink($this->data_dir . "/" . $name);
		}

		unset($_SESSION["user_payload"][$name]);

		return $retval;
	}

	function return_form () {
		global $global, $string;

		// find already inserted payload.
		$ret = $this->return_name();

		if (count($ret) < 10) {
			$var["inserted_payload_num"] = 10;
		} else {
			$var["inserted_payload_num"] = count($ret) + 1;
		}

		if (count($ret) > 0) {
			while (list($i, $j) = each($ret)) {
					$var["inserted_payload"] .=
						sprintf("<option onClick=\"viewPayload('payload','%s');\"
							value=\"%s\">%s\n", $j, $i, $j);
			}
		} else {
			$var["inserted_payload"] =
				sprintf("<option value=\"\">%s\n", $string["message13"]);
		}

		$retval =
			$this->Template->generate("/module/message/template/add_payload", $var);

		return $retval;
	}

	function message_form ($boundary) {

		$EmailData = new EmailData;

		reset($_SESSION["user_payload"]);

		while (list($i, $j) = each($_SESSION["user_payload"])) {
			$f = implode("", file($this->data_dir . "/" . $i));
			$data = preg_replace("/\n$/", "", $EmailData->encode($f));
			unset($f);

			$p["payloadBody"] = $data;
			unset($data);

			$p["type"] = $j["type"];
			$p["filename"] = $j["name"];
			$p["boundary"] = $boundary;

			$msg[] = $this->Template->generate("/module/message/template/messagePayload", $p);
		}

		return implode("\n", $msg);
	}

	function save ($data) {
		global $global;

		$save_dir = sprintf("%s/payload/%s", $global["data"], $_SESSION["config_id"]);

		if (! is_dir($save_dir)) { // check whether directory exists or not.
			if (! mkdir($save_dir)) { // create directory.
				$retval = false;
			}
		} else {
			if (! is_writable($save_dir)) {
				$retval = false;
			} else {
				// make random file name.
				$file_id = sprintf("%s.%s", mktime(), rand());
				$file_path = sprintf("%s/%s", $save_dir, $file_id);

				// save data as random file name.
				$fh = fopen($file_path, "w");
				fwrite($fh, $data);
				fclose($fh);

				$retval = $file_id;
			}
		}

		return $retval;
	}
}


/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>

==> mesian-v0.1.2.tar.bz2: mesian-v0.1.2/www-data/lib/Payload.php <==
<?

include_once $global["root"] . "/lib/EmailData.php";
include_once $global["root"] . "/lib/Template.php";

class Payload_Forum {

	var $data_dir;
	var $Template;
	var $storedFilename;
	var $header;

	var $total_size;

	var $id;

	function Payload_Forum ($id) {

		$this->id = $id;

		$this->__check();
	}

	function __check () {
		global $global;

		$this->data_dir = sprintf("%s/forum/%s", $global["data"], $this->id);

		if (! is_dir($this->data_dir)) {
			$retval = mkdir($this->data_dir);
		} else {
			$retval = true;
		}

		return $retval;
	}

	function insert () {
		global $string;

		$retval = true;

		// check file size.
		if (! $_FILES["user_payload"]["tmp_name"]) {
			$retval = false;
			$_SESSION["tmp"]["msg"]["content"] = $string["error6"];
		}

		if ($retval and $_FILES["user_payload"]["size"] < 1) {
			$retval = false;
			$_SESSION["tmp"]["msg"]["content"] = $string["error7"];
		}

		if ($retval and $_FILES["user_payload"]["size"] >
				$_SESSION["config_message_size_limit"]) {
			$retval = false;

			$_SESSION["tmp"]["msg"]["content"] =
				sprintf($string["error8"], $_SESSION["config_message_size_limit"]);
		}

		if ($retval) {

			$file_id = mktime().mt_rand(0,20);

			$storedFilename = $this->data_dir . "/" . $file_id;

			if (move_uploaded_file($_FILES["user_payload"]["tmp_name"], $storedFilename)) {
				$retval = true;
				$this->storedFilename = $file_id;
				$this->header = sprintf("%s;%s",
					$_FILES["user_payload"]["type"],
					$_FILES["user_payload"]["name"]);
			} else {
				$retval = false;
				$_SESSION["tmp"]["msg"]["content"] = $string["error2"];
			}
		}

		return $retval;
	}
}

class Payload {

	var $data_dir;
	var $Template;

	var $total_size;

	function Payload () {
		$this->__check();
		$this->Template = new Template;
	}

	function __check () {
		global $global;

		$this->data_dir = sprintf("%s/message/%s", $global["data"], $_SESSION["config_id"]);

		if (! is_dir($this->data_dir)) {
			$retval = mkdir($this->data_dir);
		} else {
			$retval = true;
		}

		return $retval;
	}

	function clean () {
		if (is_array($_SESSION["user_payload"]) and count($_SESSION["user_payload"]) > 0) {
			reset($_SESSION["user_payload"]);
			while (list($i, $j) = each($_SESSION["user_payload"])) {
				$this->remove($i);
			}

			unset($_SESSION["user_payload"]);
		}

		return true;
	}

	function return_name () {

		$dh = opendir($this->data_dir);

		while (($file = readdir($dh)) !== false) {

			$ff = $this->data_dir . "/" . $file;

			if (is_dir($ff)) continue;
			if (! is_file($ff)) continue;

			if (! array_key_exists($file, $_SESSION["user_payload"])) {
				$this->remove($file);
				continue;
			}
			$this->total_size += filesize($ff);

			$var[$file] = $_SESSION["user_payload"][$file]["name"];
		}

		closedir($dh);

		$retval = $var;

		return $retval;
	}

	// $name is real name.
	function check_duplicated ($name) {

		$retval = false;

		if (! array_key_exists("user_payload", $_SESSION)) {
			$retval = false;
		} else {
			while (list($i, $j) = each($_SESSION["user_payload"])) {
				if ($j["name"] == $name) $retval = true;
			}
		}

		return $retval;
	}

	function insert () {
		global $string;

		$retval = true;

		// check file size.
		if (! $_FILES["userfile"]["tmp_name"]) {
			$retval = false;
			$_SESSION["tmp"]["msg"]["content"] = $string["error6"];
		}

		if ($retval and $_FILES["userfile"]["size"] < 1) {
			$retval = false;
			$_SESSION["tmp"]["msg"]["content"] = $string["error7"];
		}

		if ($retval and $this->total_size + $_FILES["userfile"]["size"] >
				$_SESSION["config_message_size_limit"]) {
			$retval = false;

			$_SESSION["tmp"]["msg"]["content"] =
				sprintf($string["error8"], $_SESSION["config_message_size_limit"]);
		}

		if ($retval and $this->check_duplicated($_FILES["userfile"]["name"])) {
			$retval = false;
			$_SESSION["tmp"]["msg"]["content"] =
				sprintf($string["error1"], $_FILES["userfile"]["name"]);
		}

		if ($retval) {

			$file_id = mktime().mt_rand(0,20);

			$storedFilename = $this->data_dir . "/" . $file_id;

			if (move_uploaded_file($_FILES["userfile"]["tmp_name"], $storedFilename)) {
				$retval = true;
			} else {
				$retval = false;
				$_SESSION["tmp"]["msg"]["content"] = $string["error2"];
			}
		}

		if ($retval) {
			$_SESSION["user_payload"][$file_id]["name"] = $_FILES["userfile"]["name"];
			$_SESSION["user_payload"][$file_id]["type"] = $_FILES["userfile"]["type"];
		}

		return $retval;
	}

	function remove ($name) {
		if (! file_exists($this->data_dir . "/" . $name)) {
			$retval = false;
		} else {
			unlink($this->data_dir . "/" . $name);
		}

		unset($_SESSION["user_payload"][$name]);

		return $retval;
	}

	function return_form () {
		global $global, $string;

		// find already inserted payload.
		$ret = $this->return_name();

		if (count($ret) < 10) {
			$var["inserted_payload_num"] = 10;
		} else {
			$var["inserted_payload_num"] = count($ret) + 1;
		}

		if (count($ret) > 0) {
			while (list($i, $j) = each($ret)) {
					$var["inserted_payload"] .=
						sprintf("<option onClick=\"viewPayload('payload','%s');\"
							value=\"%s\">%s\n", $j, $i, $j);
			}
		} else {
			$var["inserted_payload"] =
				sprintf("<option value=\"\">%s\n", $string["message13"]);
		}

		$retval =
			$this->Template->generate("/module/message/template/add_payload", $var);

		return $retval;
	}

	function message_form ($boundary) {

		$EmailData = new EmailData;

		reset($_SESSION["user_payload"]);

		while (list($i, $j) = each($_SESSION["user_payload"])) {
			$f = implode("", file($this->data_dir . "/" . $i));
			$data = preg_replace("/\n$/", "", $EmailData->encode($f));
			unset($f);

			$p["payloadBody"] = $data;
			unset($data);

			$p["type"] = $j["type"];
			$p["filename"] = $j["name"];
			$p["boundary"] = $boundary;

			$msg[] = $this->Template->generate("/module/message/template/messagePayload", $p);
		}

		return implode("\n", $msg);
	}

	function save ($data) {
		global $global;

		$save_dir = sprintf("%s/payload/%s", $global["data"], $_SESSION["config_id"]);

		if (! is_dir($save_dir)) { // check whether directory exists or not.
			if (! mkdir($save_dir)) { // create directory.
				$retval = false;
			}
		} else {
			if (! is_writable($save_dir)) {
				$retval = false;
			} else {
				// make random file name.
				$file_id = sprintf("%s.%s", mktime(), rand());
				$file_path = sprintf("%s/%s", $save_dir, $file_id);

				// save data as random file name.
				$fh = fopen($file_path, "w");
				fwrite($fh, $data);
				fclose($fh);

				$retval = $file_id;
			}
		}

		return $retval;
	}
}


/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>
